# *- coding: utf-8 -*-
"""
"""
# Copyright ©  2017 Justin Stout <justin@jstout.us>
#
import os
import tarfile
import tempfile

from datetime import datetime
from pathlib import Path

import click
import gnupg

from js_dev_cfg import get_cfg_files
from js_dev_cfg import get_env_vars
from js_dev_cfg import link_files

@click.group()
def cli():
    pass

@click.command()
@click.argument('command', required=1)
def configure(command):
    """
    COMMAND: host|vagrant|project
    """
    env_vars = get_env_vars(platform=command)

    if command == 'host':
        print('Configure host -- Not Implemented')

    elif command == 'project':
        print('Configure project -- Not Implemented')

    elif command == 'vagrant':
        cfg_files = get_cfg_files(cfg_files={},
                                  root_dir=env_vars['CONFIG_DIR'],
                                  location=env_vars['LOCATION'])

        cfg_files = get_cfg_files(cfg_files=cfg_files,
                                  root_dir=env_vars['CONFIG_DIR'],
                                  location=env_vars['LOCATION'])

        link_files(cfg_files=cfg_files)

    else:
        print('Unknown Command: {}'.format(command))

@click.command()
def backup():
    """
    Backup dev_config dir.
    """
    env_vars = get_env_vars(platform='host')

    gnupghome = str(Path('~/.gnupg').expanduser())
    gpg_receipents = [env_vars['BACKUP_RECEIPIENT']]

    src_path = env_vars['CONFIG_DIR']

    dst_name = '{}_dev_cfg.tar.bz2.gpg'.format(
        datetime.utcnow().strftime('%y%m%d_%H%M%SZ')
        )

    dst_path = Path(env_vars['BACKUP_DIR'])
    dst_path.mkdir(parents=True, exist_ok=True)
    dst_path = str(dst_path / dst_name)

    tmp_tar = tempfile.TemporaryFile()
    tar_file = tarfile.open(mode='w:bz2', fileobj=tmp_tar)
    tar_file.add(src_path, arcname='dev_cfg')
    tar_file.close()

    tmp_tar.flush()
    tmp_tar.seek(0)

    gpg = gnupg.GPG(gnupghome=gnupghome)
    enc_data = gpg.encrypt_file(tmp_tar,
                                gpg_receipents,
                                armor=False,
                                output=dst_path
                                )

    tmp_tar.close()

cli.add_command(configure)
cli.add_command(backup)
