# -*- coding: utf-8 -*-
# pylint: disable=bad-continuation
""" Short description.
"""
# Copyright ©  2017 Justin Stout <justin@jstout.us>
#

import os
import sys

from pathlib import Path

from pprint import pprint as pp

def get_cfg_files(**kwargs):
    """
    Return a dictionary of Path objects where:
        key = destination path
        value = source path

    A directory with name 'home' is converted to user's home directory
        (ex: home -> /home/ubuntu)

    If cfg_files != {} then an existing destination path is overwriten with a
        new source file (ex: override default cfg file with a location specific
            file)

    kwargs:
        cfg_files(dict):    A dictionary containing currently known destination
                            paths as source files.
        location(str):  Our current development location (home, shop, job_1, etc)
        root_dir(Path): Path to file source dir (default: /dev_config/host/config_files)
    """
    cfg_files = kwargs['cfg_files']
    location = kwargs.get('location', 'default')
    root_dir = kwargs.get('root_dir', Path('/dev_config'))
    src_dir = root_dir / location

    for dirpath, dirs, files in os.walk(str(src_dir)):
        for file_ in files:
            path_str = '{}/{}'.format(dirpath, file_)
            src_path = Path(path_str)
            dst_path = Path(path_str).relative_to(src_dir)

            if dst_path.parts[0] == 'home':
               dst_path = Path.home() / dst_path.relative_to(Path('home'))

            cfg_files[dst_path] = src_path

    return cfg_files

def link_files(**kwargs):
    """
    Take a dict of filenames and sources and link them to destination.

    kwargs:
        cfg_files(dict): cfg_files dict as returned by get_cfg_files()
    """
    cfg_files = kwargs['cfg_files']

    for dst_path, src_path in cfg_files.items():
        os.makedirs(str(dst_path.parent), exist_ok=True)
        os.symlink(str(src_path), str(dst_path))
